@@ -496,7 +496,7 @@ angle.matrix<-function(RR,node,Y=NULL,select.axes=c("no","yes"),type=c("phenotyp
         data.frame(group=group,age=age,angle=mat2[,1])->mat3
         as.numeric(as.character(mat3$age))->mat3$age
 
-        if(class(try(smatr::sma(angle~age*group,data=mat3)->res.slope,silent=TRUE))=="try-error") {
+        if(inherits(try(smatr::sma(angle~age*group,data=mat3)->res.slope,silent=TRUE),"try-error")) {
 
           summary(lm(angle~group/age-1,data=mat3))->a
           t(a$coef[c(3,4),c(1,4)])->a1
