@@ -1,5 +1,5 @@
 #'@title Plot RRphylo rates at a specified node
-#'@usage plotRates(RR,node,export.tiff =FALSE,foldername=NULL,filename=NULL)
+#'@usage plotRates(RR,node,export.tiff =FALSE,filename=NULL)
 #'@description The function \code{plotRates} plots the \code{\link{RRphylo}}
 #'  rates computed for a given clade as compared to the rates computed for the
 #'  rest of the tree.
@@ -7,16 +7,13 @@
 #'@param node the node subtending the clade of interest.
 #'@param export.tiff if \code{TRUE} the function save a "rate_bars.tiff" file
 #'  inside the working directory. It is \code{TRUE} by default.
-#' @param foldername has been deprecated; please see the argument
-#'   \code{filename} instead.
 #' @param filename a character indicating the name of the tiff file and the path
 #'   where it is to be saved. If no path is indicated the file is stored in the
 #'   working directory.
 #'@export
 #' @seealso \href{../doc/RRphylo.html}{\code{RRphylo} vignette}
-#' @importFrom graphics hist par
 #'@importFrom grDevices tiff
-#'@importFrom graphics abline barplot legend
+#'@importFrom graphics abline barplot legend hist par
 #'@return The function produces two barplots. On the left side, the rates (in
 #'  absolute values) computed for the focal clade (blue) are plotted against the
 #'  rates of the rest of the tree (green). On the right side, the absolute rates
@@ -39,14 +36,9 @@
 
 
 
-plotRates<-function(RR, node, export.tiff=FALSE,foldername=NULL,filename=NULL){
+plotRates<-function(RR, node, export.tiff=FALSE,filename=NULL){
   #require(phytools)
 
-  if(!missing(foldername)){
-    stop("argument foldername is deprecated; please use filename instead.",
-         call. = FALSE)
-  }
-
   RR$rates->FULLrates
   RR$tree->rr3
   getDescendants(rr3,node)->shift331
